<?php

/**
 * Copyright (c) 2020 Tawfek Daghistani - ConfigureTech
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

namespace Ctech\Configurator\Controller\Adminhtml\Installer;

use Ctech\Configurator\Helper\Data;
use Magento\Framework\Controller\ResultInterface;
use Magento\Framework\Exception\LocalizedException;
use function GuzzleHttp\json_decode;
use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Backend\Model\Session;
use Magento\Framework\Json\Helper\Data as JsonHelper;
use Magento\Framework\View\Result\PageFactory;

class Install extends Action
{

    /** @var Data $helper */
    protected $helper;

    /** @var PageFactory $resultPageFactory */
    protected $resultPageFactory;

    /** @var JsonHelper $jsonHelper */
    protected $jsonHelper;

    /** @var  Session $session  */
    protected $session;

    /**
     *
     *
     * @param Context $context
     * @param PageFactory $resultPageFactory
     * @param JsonHelper $jsonHelper
     * @param Session $session
     * @param Data $helper
     */
    public function __construct(
        Context $context,
        PageFactory $resultPageFactory,
        JsonHelper $jsonHelper,
        Session $session,
        Data $helper
    ) {
        $this->resultPageFactory = $resultPageFactory;
        $this->jsonHelper = $jsonHelper;
        $this->helper = $helper;
        $this->session = $session;
        parent::__construct($context);
    }

    /**
     * Execute view action
     *
     * @return ResultInterface
     */
    public function execute()
    {
        try {
            $data = $this->getRequest()->getPostValue();
            if (!empty($data) && $this->getRequest()->isAjax()) {
                $selection = json_decode($data["selection"], true);
                foreach ($selection as $item) {
                    $categories = $item["categories"];
                    $currentItem = explode("||", $item["item"]);
                    $brandCode = $currentItem[0];
                    $lineCode = $currentItem[1];
                    $this->helper->addProductToCron([
                        'brandCode' => $brandCode,
                        'lineCode' => $lineCode,
                        'categories' => $categories
                    ]);
                }
                return $this->jsonResponse(['success' => 'true', 'message' => 'Products have been added to queue']);
            } else {
                return $this->jsonResponse(['success' => 'false', 'message' => 'POST has no values']);
            }
        } catch (LocalizedException $e) {
            return $this->jsonResponse(['success' => 'false', 'message' => $e->getMessage()]);
        } catch (\Exception $e) {
            return $this->jsonResponse(['success' => 'false', 'message' => $e->getMessage()]);
        }
    }

    /**
     * Create json response
     *
     * @param string $response
     * @return ResultInterface
     */
    public function jsonResponse($response = '')
    {
        return $this->getResponse()->representJson(
            $this->jsonHelper->jsonEncode($response)
        );
    }
}
